﻿
/*******************************************************/
/**                Formation aux outils               **/
/**              Atelier Technique - SAS              **/
/**                                                   **/
/**  Statistiques descriptives univariées, graphiques **/
/**                     Groupe n°3                    **/
/*******************************************************/


/* 1. Création d'une bibliothèque et importation du fichier 'World_cup.csv'.  */
LIBNAME MaLib '/folders/myfolders' ;

PROC IMPORT datafile='/folders/myfolders/WorldCups.csv' dbms=csv out=Malib.world_cups ;
			getnames=YES ;
			datarow=2 ;
RUN ;


/* 2. Affichage des données. */
PROC PRINT data=malib.world_cups ;
RUN ;


/* 3. Champs (variables) et observations (enregistrements) dans le fichier. */
PROC CONTENTS data=malib.world_cups ;
RUN ;


/* 4.a. Affichage des principales statistiques des variables numériques en fonction de la variable ‘Winner’. */
	/* D’abord avec l’option CLASS... */
PROC MEANS 	data=malib.world_cups ;
			class Winner ;
RUN ;
	/* ... puis en utilisant l’option BY (nécessité de trier avec avant) */
PROC SORT 	data=malib.world_cups ;
			by Winner ;
RUN ;
PROC MEANS 	data=malib.world_cups ;
			by Winner ;
RUN ;

/* 4.b. Utilisation de la procédure UNIVARIATE sur la variable 'Attendance' */
PROC UNIVARIATE data=malib.world_cups ;
				var Attendance ;
RUN ;


/* 5. Pays ayant accueilli le plus de CDM.  */
PROC FREQ 	data=malib.world_cups order=freq ;
			table Country ;
RUN ;


/* 6. Equipes ayant gagné à domicile  */
PROC FREQ 	data=malib.world_cups ;
			where Winner = Country ;
			table Winner ;
RUN ;


/* 7a. Diagramme à barres, trié du plus grand au plus petit, du nombre de CDM gagnées par pays.*/
	/* Solution avec SGPLOT */
PROC SGPLOT data=malib.world_cups ;
			vbar Winner / categoryorder=respdesc ;
RUN;
	/* Solution avec CHART */
PROC CHART 	data=malib.world_cups ;
			vbar Winner / DESC ;
RUN ;

/* 7b. Camembert*/
PROC TEMPLATE;
		define statgraph SASStudio.Pie;
		begingraph;
		layout region;
		piechart category=Winner /;
		endlayout;
		endgraph;
	end;
RUN;

ods graphics / reset width=6.4in height=4.8in imagemap;

PROC SGRENDER template=SASStudio.Pie data=MALIB.WORLD_CUPS;
RUN;

ods graphics / reset;


/* 8a. Nombre de buts marqués moyens selon le nombre de matchs joués ainsi que le nombre d’observations correspondantes. */
PROC UNIVARIATE data=malib.world_cups ;
				class MatchesPlayed ;
				var GoalsScored ;
				output out=malib.question8 n=Nobs mean=AvgGoal ;
RUN ;

/* 8b. Nuage de points du nombre de buts moyens en fonction du nombre de matchs joués. */
	/* Avec plot */
title 'Nombre de buts moyens en fonction du nombre de matchs joués';
PROC PLOT 	data=malib.question8 ;
			plot AvgGoal*Matchesplayed ;
RUN ;
title ;
	/* Avec scatter plot */
PROC SGPLOT data=malib.question8 ;
			scatter x=MatchesPlayed y=AvgGoal ;
			xaxis grid ;
			yaxis grid ;
RUN ;


/* 9. Création de la variables‘GoalsPerMatch’ : nombre de buts moyens par match pour chaque CDM. */
DATA malib.world_cups ;
	set malib.world_cups ;
	GoalsPerMatch = GoalsScored / MatchesPlayed ;
RUN;
	/* Calcul du nombre moyen de but par match sur l’ensemble des CDM. */
PROC MEANS 	data=malib.world_cups ;
			var GoalsPerMatch / weight=MatchesPlayed ;
RUN ;


/* 10. Création de la variable ‘AttendancePerMatch’ : nombre de spectateurs moyens par match. */
DATA malib.world_cups;
	set malib.world_cups;
	AttendancePerMatch = Attendance / MatchesPlayed ;
RUN ;
	/* Histogramme correspondant. */
PROC SGPLOT data=MALIB.WORLD_CUPS;
			histogram AttendancePerMatch /;
			yaxis grid;
RUN;
	/* Test de normalité. */
PROC UNIVARIATE data=MALIB.WORLD_CUPS normaltest;
				var AttendancePerMatch ;
run;


/* 11. Graphique à bulle ‘GoalsPerMatch’ en fonction de 'AttendancePerMatch' + taille des bulles selon l'année. */
PROC SGPLOT data=MALIB.WORLD_CUPS;
			bubble x=GoalsPerMatch y=AttendancePerMatch size=Year/ bradiusmin=2 bradiusmax=10;
			xaxis grid;
			yaxis grid;
RUN;


/* 12. Recodage de la variable 'AttendancePerMatch' en une variable qualitative comportant 3 modalités d’effectif égal (tercile). */
/* 12a. Terciles de la variable 'AttendancePerMatch' */
PROC UNIVARIATE data=malib.world_cups ;
  				var AttendancePerMatch ;
  				output out=malib.quantiles PCTLPRE=tercile PCTLPTS=33.33 66.66 ;
RUN ;
PROC PRINT DATA=malib.quantiles ; 

/* 12b. Recodage de la variable 'AttendancePerMatch' à l'aide des terciles déterminés précédemment */
PROC FORMAT ;
	value moda 
	low-40572="1 - Faible affluence"
	40572-48847="2 - Moyenne affluence"
	48847-high="3 - Forte affluence" ;
RUN ;
DATA malib.world_cups ;
	set malib.world_cups ;
	AttendanceModa = put(AttendancePerMatch, moda.);
RUN ;

/* 12c. Vérification */
PROC FREQ ;
	table AttendanceModa ;
RUN ;


/* 13. Tracer le boxplot conditionnel ‘GoalsPerMatch’ en fonction des modalités de 'AttendancePerMatch'. */
PROC SGPLOT data=malib.world_cups ;
			vbox GoalsPerMatch / category = AttendanceModa ;
RUN; 


/* 14. Standardisation de la variable ‘GoalsMatch’. */
PROC STDIZE data=MALIB.WORLD_CUPS method=std out=MALIB.WORLD_CUPS oprefix sprefix=Standardized_ ;
			var GoalsScored ;
RUN;
PROC MEANS data=malib.world_cups MEAN VAR ;
			var Standardized_GoalsScored ;
RUN ;


 